@@ -151,6 +151,8 @@ loglike_range <- function(sem_out, par_i,
     if (parallel) {
         # Parallel
         cl <- parallel::makeCluster(ncpus)
+        on.exit(try(parallel::stopCluster(cl),
+                    silent = TRUE))
         # Rebuild the environment
         pkgs <- .packages()
         pkgs <- rev(pkgs)
@@ -378,6 +380,8 @@ loglike_quad_range <- function(sem_out,
     if (parallel) {
         # Parallel
         cl <- parallel::makeCluster(ncpus)
+        on.exit(try(parallel::stopCluster(cl),
+                    silent = TRUE))
         # Rebuild the environment
         pkgs <- .packages()
         pkgs <- rev(pkgs)
