@@ -171,6 +171,8 @@ loglike_range_ur <- function(sem_out,
     if (parallel) {
         # Parallel
         cl <- parallel::makeCluster(ncpus)
+        on.exit(try(parallel::stopCluster(cl),
+                    silent = TRUE))
         # Rebuild the environment
         pkgs <- .packages()
         pkgs <- rev(pkgs)
@@ -326,6 +328,8 @@ loglike_quad_range_ur <- function(sem_out,
     if (parallel) {
         # Parallel
         cl <- parallel::makeCluster(ncpus)
+        on.exit(try(parallel::stopCluster(cl),
+                    silent = TRUE))
         # Rebuild the environment
         pkgs <- .packages()
         pkgs <- rev(pkgs)
