@@ -5,7 +5,7 @@ library(semlbci)
 
 # Fit the model
 
-library(lavaan)
+suppressMessages(library(lavaan))
 
 data(simple_med_mg)
 dat <- simple_med_mg
@@ -43,10 +43,26 @@ time2u <- system.time(out2u <- ci_bound_wn_i(10, 16, sem_out = fit, f_constr = f
 # 2023-10-23: Updated precomputed answers manually checked for validity.
 # 2023-10-23: Tolerance updated to allow for cross-platform differences.
 test_that("Check against precomputed answers", {
-    expect_equal(out1l$bound, -0.190309, tolerance = 1e-3)
-    expect_equal(out1u$bound, 2.752005, tolerance = 1e-4)
-    expect_equal(out2l$bound, 0.362989, tolerance = 1e-4)
-    expect_equal(out2u$bound, 0.7840242, tolerance = 1e-4)
+    # 2025-12-04:
+    # Increase the tolerance due to changes in lavaan optimization
+    # lavaan 0.6-21:     -0.1900844
+    # lavaan pre 0.6-21: -0.190309
+    # lavaan 0.6-21:
+    # lavaan pre 0.6-21:
+    expect_equal(out1l$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out1u$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out1l$bound, -0.190309, tolerance = 1e-2)
+    expect_equal(out1u$bound, 2.752005, tolerance = 1e-3)
+    # 2025-12-04:
+    # Increase the tolerance due to changes in lavaan optimization
+    # lavaan 0.6-21:
+    # lavaan pre 0.6-21:
+    # lavaan 0.6-21:
+    # lavaan pre 0.6-21:
+    expect_equal(out2l$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out2u$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out2l$bound, 0.362989, tolerance = 1e-3)
+    expect_equal(out2u$bound, 0.7840242, tolerance = 1e-3)
   })
 
 skip("Run only if data changed")
