@@ -5,7 +5,7 @@ library(semlbci)
 
 # Fit the model
 
-library(lavaan)
+suppressMessages(library(lavaan))
 
 data(simple_med_mg)
 dat <- simple_med_mg
@@ -35,8 +35,16 @@ time2u <- system.time(out2u <- ci_bound_wn_i(1, 16, sem_out = fit, f_constr = fn
 
 # 2023-10-23: Updated precomputed answers manually checked for validity.
 test_that("Check against precomputed answers", {
-    expect_equal(out1l$bound, 0.06101715, tolerance = 1e-4)
-    expect_equal(out2u$bound, 0.4024136, tolerance = 1e-4)
+    # 2025-12-04:
+    # Increase the tolerance due to changes in lavaan optimization
+    # lavaan 0.6-21:     0.05979616
+    # lavaan pre 0.6-21: 0.06101715
+    # lavaan 0.6-21:     0.4041206
+    # lavaan pre 0.6-21: 0.4024136
+    expect_equal(out1l$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out2u$diag$ciperc_final, .96, tolerance = 1e-3)
+    expect_equal(out1l$bound, 0.06101715, tolerance = 1e-1)
+    expect_equal(out2u$bound, 0.4024136, tolerance = 1e-2)
   })
 
 skip("Run only if data changed")
