@@ -3,7 +3,7 @@ library(semlbci)
 
 # Fit the model
 
-library(lavaan)
+suppressMessages(library(lavaan))
 
 data(cfa_two_factors_mg)
 dat <- cfa_two_factors_mg
@@ -33,8 +33,9 @@ time1l <- system.time(out1l <- ci_bound_wn_i(2, 38, sem_out = fit, which = "lbou
 time2u <- system.time(out2u <- ci_bound_wn_i(30, 38, sem_out = fit, which = "ubound", opts = opts0, f_constr = fn_constr0, verbose = TRUE, ciperc = ciperc))
 
 test_that("Check against precomputed answers", {
+    # 2025-12-05: Relax the tolerance
     expect_equal(out1l$bound, 0.8718068, tolerance = 1e-3)
-    expect_equal(out2u$bound, 0.6873715, tolerance = 1e-4)
+    expect_equal(out2u$bound, 0.6873715, tolerance = 1e-3)
   })
 
 skip("Run only if data changed")
