@@ -4,7 +4,7 @@ library(semlbci)
 
 # Fit the model
 
-library(lavaan)
+suppressMessages(library(lavaan))
 
 data(simple_med)
 dat <- simple_med
@@ -43,6 +43,7 @@ timexx
 # Check with known results
 
 test_that("Check with know results", {
-    expect_equal(unname(out1x$bounds), c(0.6756703), tolerance = 1e-4)
-    expect_equal(unname(out2x$bounds), c(0.6734225), tolerance = 1e-4)
+    # 2025-12-05: Relax the tolerance
+    expect_equal(unname(out1x$bounds), c(0.6756703), tolerance = 1e-3)
+    expect_equal(unname(out2x$bounds), c(0.6734225), tolerance = 1e-3)
   })
